Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(159)

Unified Diff: src/heap/spaces.cc

Issue 1899193005: Version 5.1.281.9 (cherry-pick) (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@5.1
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/heap/incremental-marking.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap/spaces.cc
diff --git a/src/heap/spaces.cc b/src/heap/spaces.cc
index 279ac94194256ccc35815f0f896e0de8a993f8d7..63e7c33c5822c1b21f3a391fb02b0167d5eb7a48 100644
--- a/src/heap/spaces.cc
+++ b/src/heap/spaces.cc
@@ -1191,9 +1191,10 @@ bool PagedSpace::Expand() {
// Pages created during bootstrapping may contain immortal immovable objects.
if (!heap()->deserialization_complete()) p->MarkNeverEvacuate();
// When incremental marking was activated, old generation pages are allocated
// black.
- if (heap()->incremental_marking()->black_allocation()) {
+ if (heap()->incremental_marking()->black_allocation() &&
+ identity() == OLD_SPACE) {
Bitmap::SetAllBits(p);
p->SetFlag(Page::BLACK_PAGE);
if (FLAG_trace_incremental_marking) {
@@ -2929,11 +2930,6 @@ AllocationResult LargeObjectSpace::AllocateRaw(int object_size,
}
HeapObject* object = page->GetObject();
- if (heap()->incremental_marking()->black_allocation()) {
- MarkBit mark_bit = Marking::MarkBitFrom(object);
- Marking::MarkBlack(mark_bit);
- page->SetFlag(Page::BLACK_PAGE);
- }
MSAN_ALLOCATED_UNINITIALIZED_MEMORY(object->address(), object_size);
if (Heap::ShouldZapGarbage()) {
« no previous file with comments | « src/heap/incremental-marking.cc ('k') | no next file » | no next file with comments »
@@ -1191,9 +1191,10 @@ bool PagedSpace::Expand() {
// Pages created during bootstrapping may contain immortal immovable objects.
if (!heap()->deserialization_complete()) p->MarkNeverEvacuate();
- // When incremental marking was activated, old generation pages are allocated
+ // When incremental marking was activated, old space pages are allocated
// black.

Powered by Google App Engine
This is Rietveld 408576698